@@ -1,21 +1,7 @@
 /*
  *  Copyright 2013  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef UNIT_H
@@ -51,6 +37,8 @@ public:
     void setCourse(std::shared_ptr<ICourse> course) override;
     QString title() const override;
     void setTitle(const QString &title) override;
+    QString i18nTitle() const override;
+    void setI18nTitle(const QString &title) override;
     QVector<std::shared_ptr<IPhrase>> phrases() const override;
     void addPhrase(std::shared_ptr<IEditablePhrase> phrase, int index) override;
     void removePhrase(std::shared_ptr<IPhrase> phrase) override;
@@ -68,6 +56,7 @@ private:
     QString m_foreignId;
     std::weak_ptr<ICourse> m_course;
     QString m_title;
+    QString m_i18nTitle;
     QVector<std::shared_ptr<IPhrase>> m_phrases;
 };
 
